CacheInitConfig class
缓存配置
Constructors
- CacheInitConfig({bool enableAutoClean = true, Duration autoCleanInterval = const Duration(hours: 1), int maxCacheSizeMB = 100})
Properties
- autoCleanInterval → Duration
-
自动清理间隔
final
- enableAutoClean → bool
-
是否启用自动清理
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxCacheSizeMB → int
-
最大缓存大小(MB)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited