MockConfig class

Mock配置

Constructors

MockConfig()

Properties

currentScenario String?
当前场景
getter/setter pair
enabled bool
是否启用Mock
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mocks List<MockData>
Mock数据列表(支持多个匹配器)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
清空所有 Mock
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(MockData mock) → void
注册Mock数据
registerAll(List<MockData> mockList) → void
批量注册
remove(MockData mock) → void
移除指定 Mock
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited