LoggerConfig class

PrettyDioLogger 配置类 用于配置日志打印的详细信息

Constructors

LoggerConfig({bool requestHeader = true, bool requestBody = true, bool responseHeader = false, bool responseBody = true, bool error = true, int maxWidth = 160, bool compact = true, bool? enabled})

Properties

compact bool
请求的紧凑模式
final
enabled bool?
是否启用日志拦截器 如果为null,则根据编译模式自动判断(debug模式启用,release模式禁用)
final
error bool
是否打印错误信息
final
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
获取实际是否启用,如果enabled为null则根据编译模式判断
no setter
maxWidth int
每个请求的最大打印宽度
final
requestBody bool
是否打印请求体
final
requestHeader bool
是否打印请求头
final
responseBody bool
是否打印响应体
final
responseHeader bool
是否打印响应头
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited