NetworkConstants class
网络请求常量
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultAutoCleanInterval → const Duration
- 默认自动清理间隔
- defaultCacheExpiration → const Duration
- 默认缓存过期时间
- defaultCachePriority → const int
- 默认缓存优先级
- defaultConnectTimeout → const Duration
- 默认连接超时时间
- defaultMaxCacheSizeMB → const int
- 默认最大缓存大小(MB)
- defaultMaxRetries → const int
- 默认最大重试次数
- defaultReceiveTimeout → const Duration
- 默认接收超时时间
- defaultRetryInterval → const Duration
- 默认重试间隔
- defaultTokenHeader → const String
- 默认Token请求头key
- defaultTokenPrefix → const String
- 默认Token前缀
- defaultTokenUseSpace → const bool
- Token前缀后是否需要空格
- fieldCode → const String
- 响应码字段名
- fieldData → const String
- 响应数据字段名
- fieldMessage → const String
- 响应消息字段名
- fieldResult → const String
- 响应结果字段名
- statusForbidden → const int
- 禁止访问状态码
- statusNotFound → const int
- 未找到状态码
- statusServerError → const int
- 服务器错误状态码
- 未授权状态码
-
successCodes
→ const List<
int> - 成功状态码列表